Module entry

Module entry 

Handling of archive entries and their name

Structs

ArchiveEntry
Represents an entry in the archive.
ArchiveEntryDataReader
Structure available in an ArchiveEntry data field, enabling one to Read and Seek inside an archive entry.
ArchiveEntryId
Represents a unique identifier for an entry in the archive. Used to maintain references to entries while writing an archive.
EntryName
Arbitrary bytes representing an archive entry name. WARNING, see rest of its documentation.

Enums

EntryNameError

Statics

ENTRY_NAME_PATHBUF_ESCAPED_STRING_ALLOWED_BYTES
Allowed bytes in EntryName::to_pathbuf_escaped_string output. Documented there.
ENTRY_NAME_RAW_CONTENT_ALLOWED_BYTES
Allowed bytes in EntryName::raw_content_to_escaped_string output. Documented there.