Handling of archive entries and their name
Structs
- Archive
Entry - Represents an entry in the archive.
- Archive
Entry Data Reader - Structure available in an
ArchiveEntrydatafield, enabling one toReadandSeekinside an archive entry. - Archive
Entry Id - Represents a unique identifier for an entry in the archive. Used to maintain references to entries while writing an archive.
- Entry
Name - Arbitrary bytes representing an archive entry name. WARNING, see rest of its documentation.
Enums
Statics
- ENTRY_
NAME_ PATHBUF_ ESCAPED_ STRING_ ALLOWED_ BYTES - Allowed bytes in
EntryName::to_pathbuf_escaped_stringoutput. Documented there. - ENTRY_
NAME_ RAW_ CONTENT_ ALLOWED_ BYTES - Allowed bytes in
EntryName::raw_content_to_escaped_stringoutput. Documented there.